@@ -15,7 +15,7 @@ use futures::future::join_all;
 /// use std::any::Any;
 /// // Create new topic
 /// type Topic = ();
-/// 
+///
 /// // Impl our subscriber
 /// struct SimpleSubscriber;
 /// #[async_trait]
@@ -122,8 +122,8 @@ pub trait Subscriber {
 /// // Create new topic from empty type
 /// type Topic = ();
 /// // Our subscriber
-/// fn subscriber(message: &dyn Any) {}
-/// 
+/// fn subscriber(message: &(dyn Any + Send + Sync)) {}
+///
 /// async fn subscribe_on_topic() {
 ///     // Create new event bus
 ///     let mut event_bus = EventBus::new().await;
@@ -131,7 +131,7 @@ pub trait Subscriber {
 ///     event_bus.subscribe::<Topic>(Box::new(SubscriberFn::new(subscriber))).await;
 /// }
 /// ```
-pub struct SubscriberFn(fn(&dyn Any) -> ());
+pub struct SubscriberFn(fn(&(dyn Any + Send + Sync)) -> ());
 #[async_trait]
 impl Subscriber for SubscriberFn {
     async fn handle(&self, message: &(dyn Any + Send + Sync)) {
@@ -139,44 +139,72 @@ impl Subscriber for SubscriberFn {
     }
 }
 impl SubscriberFn {
-    pub fn new(func: fn(&dyn Any) -> ()) -> SubscriberFn {
+    pub fn new(func: fn(&(dyn Any + Send + Sync)) -> ()) -> SubscriberFn {
         SubscriberFn { 0: func }
     }
 }
 
 #[cfg(test)]
 mod tests {
-    use std::any::Any;
+    
 
-    use crate::{EventBus, Subscriber};
-    use async_trait::async_trait;
+    use crate::{EventBus, SubscriberFn};
+    
+    mod subscribers {
+        use std::any::Any;
 
-    type Topic = ();
-    struct SimpleSubscriber;
-    #[async_trait]
-    impl Subscriber for SimpleSubscriber {
-        async fn handle(&self, message: &(dyn Any + Send + Sync)) {
-            match message.downcast_ref::<String>() {
-                Some(str) => {
-                    if str != "Hello" {
-                        panic!("String != Hello")
-                    }
-                }
-                None => panic!("No string"),
+        use async_trait::async_trait;
+
+        use crate::Subscriber;
+
+        pub type Topic = ();
+
+        pub struct SimpleSubscriber;
+
+        #[async_trait]
+        impl Subscriber for SimpleSubscriber {
+            async fn handle(&self, message: &(dyn Any + Send + Sync)) {
+                check_message(message);
             }
         }
+
+        pub fn check_message(message: &(dyn Any + Send + Sync)) {
+            match message.downcast_ref::<String>() {
+                Some(message) => {
+                    if message != "Hello" {
+                        panic!("Message != Hello")
+                    }
+                }
+                None => panic!("No message"),
+            }
+        }
+        pub fn subscriber(message: &(dyn Any + Send + Sync)) {
+            check_message(message);
+        }
     }
+
     #[test]
     fn test_event_bus() {
-        let future = async {
-            let mut event_bus = EventBus::new().await;
-            event_bus
-                .subscribe::<Topic>(Box::new(SimpleSubscriber {}))
-                .await;
-            event_bus.publish::<Topic>(&"Hello".to_string()).await;
-        };
         futures::executor::ThreadPool::new()
             .expect("Failed to create thread pool")
-            .spawn_ok(future);
+            .spawn_ok(async {
+                let mut event_bus = EventBus::new().await;
+                event_bus
+                    .subscribe::<subscribers::Topic>(Box::new(subscribers::SimpleSubscriber {}))
+                    .await;
+                event_bus.publish::<subscribers::Topic>(&"Hello".to_string()).await;
+            });
+    }
+    #[test]
+    fn test_fn_subscriber() {
+        futures::executor::ThreadPool::new()
+            .expect("Failed to create thread pool")
+            .spawn_ok(async {
+                let mut event_bus = EventBus::new().await;
+                event_bus
+                    .subscribe::<subscribers::Topic>(Box::new(SubscriberFn::new(subscribers::subscriber))).await;
+                event_bus.publish::<subscribers::Topic>(&"Hello".to_string()).await;
+                
+            });
     }
 }
